pub fn create_api_state_with_changes(
graph: SourceCodeGraph,
git_changes: GitChangeSnapshot,
) -> Arc<ApiState>Expand description
Create a new API state with the given graph and git changes.
pub fn create_api_state_with_changes(
graph: SourceCodeGraph,
git_changes: GitChangeSnapshot,
) -> Arc<ApiState>Create a new API state with the given graph and git changes.